#!/bin/bash
#SBATCH -N 1
#SBATCH --partition=exfel
#SBATCH --time=12:00:00
#SBATCH --mail-type=END,FAIL
#SBATCH --output=logs/%j-%x.out

PROPOSAL=2784
DARK=$1
RUN=$2
GAIN=$3
ROISTH=${4:-1}
SATLEVEL=${5:-500}
MODULE=15

source /etc/profile.d/modules.sh
module load exfel
module load exfel_anaconda3/1.1

echo processing run $RUN
PDIR=$(find-proposal $PROPOSAL)
PPROPOSAL="p$(printf '%06d' $PROPOSAL)"
RDIR="$PDIR/usr/processed_runs/r$(printf '%04d' $RUN)"
mkdir $RDIR

NB='BOZ analysis part I.a Correction determination.ipynb'
KERNEL="SCS Toolbox ($PPROPOSAL)"

#activate the proposal environment
ACTIVATE="$PDIR/usr/Software/envs/toolbox_$PPROPOSAL/bin/activate"
source $ACITVATE

python -c "import papermill as pm; pm.execute_notebook(\
  '$NB', \
	'$RDIR/output.ipynb', \
  parameters=dict(proposal='$PROPOSAL', \
                  darkrun='$DARK', \
                  run='$RUN', \
                  module='$MODULE', \
                  gain='$GAIN', \
                  rois_th='$ROISTH', \
                  sat_level='$SATLEVEL', \
                  kernel='$KERNEL'))"
