from setuptools import setup, find_packages

with open('README.rst') as f:
    readme = f.read()

with open('VERSION') as f:
    _version = f.read()
    _version = _version.strip("\n")


basic_analysis_reqs = ['numpy', 'scipy',]  # and is readily available in Karabo
advanced_analysis_reqs = [
    'pandas', 'imageio', 'xarray>=0.13.0', 'psutil', 'h5py', 'h5netcdf',]
interactive_reqs = ['ipykernel', 'matplotlib', 'tqdm',]
maxwell_reqs = ['joblib', 'papermill', 'dask',
                'extra_data', 'euxfel_bunch_pattern>=0.6']


setup(name='toolbox_scs',
      version=_version,
      description="A collection of code for the SCS beamline",
      long_description=readme,
      author='SCS team',
      author_email='scs@xfel.eu',
      url="https://git.xfel.eu/gitlab/SCS/ToolBox.git",
      keywords='XAS, xgm, DSSC, FCCD, PPL',
      license="GPL",
      package_dir={'': 'src'},
      packages=find_packages('src'),
      package_data={},
      install_requires=basic_analysis_reqs,
      extras_require={
          'advanced': advanced_analysis_reqs,
          'interactive': interactive_reqs,
          'maxwell': advanced_analysis_reqs + interactive_reqs + maxwell_reqs,
          'test': ['pytest']
      }
)
